import test from 'ava';
import { dirname, isAbsolute, join, relative } from 'node:path';
import { $RefParser } from '@apidevtools/json-schema-ref-parser';
import _Ajv from 'ajv';
import loadAllSchemas from './index.js';
const Ajv = _Ajv;
export async function loadSchema(uri) {
    const r = /^https:\/\/formats\.openag\.io/i;
    if (r.test(uri)) {
        const file = uri.replace(r, '.').replace(/\.json$/, '');
        return import(file);
    }
    throw new Error(`Unknown schema URI: ${uri}`);
}
const ajv = new Ajv({
    async loadSchema(uri) {
        return loadSchema(uri);
    },
    inlineRefs: false,
    allErrors: true,
    strict: false,
    validateFormats: false,
});
test.before('Initialize JSON Schema validator', async () => {
    const meta = await $RefParser.dereference('https://json-schema.org/draft/2019-09/schema');
    ajv.addMetaSchema(meta);
});
let checkReferences;
test.before('Initialize $ref checker', () => {
    checkReferences = async (key, schema) => {
        const $refparser = new $RefParser();
        return $refparser.dereference(schema, {
            resolve: {
                file: {
                    order: 0,
                    canRead: true,
                    async read({ url }) {
                        const r = /^https:\/\/formats\.openag\.io/;
                        const directory = './';
                        const path = url.startsWith('https://formats.openag.io')
                            ? url.replace(r, '')
                            : relative('', url);
                        const file = `./${(isAbsolute(path)
                            ? join(directory, path)
                            : join(directory, dirname(key), path)).replace(/\.json$/, '.cjs')}`;
                        return import(file);
                    },
                },
            },
        });
    };
});
for await (const { schema, key } of loadAllSchemas()) {
    test.before(`Compile schema ${key}`, async () => {
        try {
            await ajv.compileAsync(schema);
        }
        catch {
        }
    });
    test(`${key} should be valid JSON Schema`, (t) => {
        t.assert(ajv.validateSchema(schema));
    });
    test(`${key} should have consistent $id`, (t) => {
        const { $id } = schema;
        t.is($id, `https://${join('formats.openag.io/', key)}`);
    });
    test.todo(`${key} should have valid self $ref's`);
    test(`${key} should have valid external $ref's`, async (t) => {
        await t.notThrowsAsync(checkReferences(key, schema));
    });
    test(`${key} should have valid default`, (t) => {
        const { default: def } = schema;
        t.plan(def ? 1 : 0);
        if (def) {
            t.assert(ajv.validate(schema, def), ajv.errorsText());
        }
    });
    test(`${key} should validate examples`, (t) => {
        const { examples = [] } = schema;
        t.plan(examples?.length ?? 0);
        for (const example of examples) {
            t.assert(ajv.validate(schema, example), ajv.errorsText());
        }
    });
}
//# sourceMappingURL=index.spec.js.map