declare const schema: {
    readonly $id: "https://formats.openag.io/trellis/audit/globalgap/v1.schema.json";
    readonly $schema: "http://json-schema.org/draft-07/schema#";
    readonly description: "A GlobalGAP audit is like a generic audit, but more restrictive.  Certain keys are marked as \"required\" here that should always exist if you have a GlobalGAP audit.";
    readonly properties: {
        readonly scheme: {
            readonly description: "the set of descriptors for identifying the current audit scheme for this document.";
            readonly properties: {
                readonly name: {
                    readonly description: "name is a string, typically the name of the object the key appears in.";
                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                    readonly enum: readonly ["GLOBALGAP"];
                    readonly examples: readonly ["PrimusGFS", "GlobalGAP", "CanadaGAP", "SQFI"];
                };
                readonly version: {
                    readonly description: "version is a string which describes the version of the schema used for the current audit.";
                    readonly type: "string";
                };
                readonly option: {
                    readonly description: "option is used as an indicator of type of audit for a given audit version.  Introduced for GlobalGAP audit, also present in CanadaGAP audit.";
                    readonly type: "string";
                };
                readonly options: {
                    readonly description: "If an audit covers multiple scheme options, you can make an array of them.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["name", "version", "option", "modules"];
            readonly type: "object";
        };
        readonly certifying_body: {
            readonly description: "specifies the credentials of the organization is performing the audit along with the specific individual performing the audit.";
            readonly properties: {
                readonly name: {
                    readonly description: "name is a string, typically the name of the object the key appears in.";
                    readonly type: "string";
                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                    readonly examples: readonly ["Primus Auditing Operations"];
                };
                readonly auditor: {
                    readonly description: "\"auditor\" is the person performing the audit for the certifying body";
                    readonly properties: {
                        readonly conflict_of_interest: {
                            readonly description: "conflict_of_interest indicates if a particular person (auditor) has a known conflict of interest for creating a certification for an organization";
                            readonly type: "boolean";
                        };
                        readonly number_prior_audits_this_organization: {
                            readonly description: "Introduced for CanadaGAP, this is the auditor's attestation of how many times they have audited this operation before.";
                            readonly type: "string";
                            readonly pattern: "^[0-9]+$";
                        };
                        readonly number_prior_consecutive_audits_this_organization: {
                            readonly description: "Introduced for CanadaGAP, this is the auditor's attestation of how many consecutive times they have audited this operation, excluding the current audit.";
                            readonly type: "string";
                            readonly pattern: "^[0-9]+$";
                        };
                    };
                    readonly type: "object";
                };
                readonly reviewer: {
                    readonly description: "Introduced for CanadaGAP audit.  Represents the person who reviewed the audit within the certifiation body.";
                    readonly properties: {
                        readonly name: {
                            readonly description: "name is a string, typically the name of the object the key appears in.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                        readonly email: {
                            readonly description: "email address for an organization or contact";
                            readonly type: "string";
                        };
                        readonly location: {
                            readonly description: "location describes the postal address used to identify where something is.";
                            readonly properties: {
                                readonly postal_code: {
                                    readonly description: "postal_code is the postal code used in a postal address";
                                    readonly type: "string";
                                };
                                readonly street_address: {
                                    readonly description: "The street name and mailbox number of a postal address.";
                                    readonly type: "string";
                                };
                                readonly city: {
                                    readonly description: "The name of the city, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly state: {
                                    readonly description: "The name of the state or major region, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly country: {
                                    readonly description: "The name of the country, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly name: {
                                    readonly description: "name is a string, typically the name of the object the key appears in.";
                                    readonly type: "string";
                                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly phone: {
                            readonly description: "phone describes the phone number with country code and area code.";
                            readonly type: "string";
                        };
                        readonly fax: {
                            readonly description: "fax number for a person or organization";
                            readonly type: "string";
                        };
                    };
                    readonly type: "object";
                };
                readonly review_date: {
                    readonly description: "Introduced for CanadaGAP.  Indicates when the review of the audit was performed.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["name", "auditor"];
            readonly type: "object";
        };
        readonly organization: {
            readonly description: "organization contains information about the organization under audit.";
            readonly properties: {
                readonly organizationid: {
                    readonly description: "organizationid identifies the organization which is the subject of the audit/certification.";
                    readonly properties: {
                        readonly id: {
                            readonly description: "An id is a string which should be reasonably unique to represent the  object it belongs to.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                        readonly id_source: {
                            readonly description: "An id_source is a representation of who assigned the id: i.e. who do you go ask to figure out what a particular ID goes to.";
                            readonly type: "string";
                            readonly examples: readonly ["scheme", "certifying_body"];
                        };
                    };
                    readonly type: "object";
                };
                readonly GLN: {
                    readonly description: "A Global Location Number, assigned by GS1.  Usually exists in \"organization\".";
                    readonly type: "string";
                    readonly pattern: "^[0-9]{13}$";
                };
                readonly name: {
                    readonly description: "name is a string, typically the name of the object the key appears in.";
                    readonly type: "string";
                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                };
                readonly contacts: {
                    readonly description: "contacts is a list of contact people for an organization.";
                    readonly type: "array";
                    readonly items: {
                        readonly description: "contact describes an individuals who may be contacted in reference to this audit.";
                        readonly properties: {
                            readonly name: {
                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                            };
                            readonly email: {
                                readonly description: "email address for an organization or contact";
                                readonly type: "string";
                            };
                            readonly location: {
                                readonly description: "location describes the postal address used to identify where something is.";
                                readonly properties: {
                                    readonly postal_code: {
                                        readonly description: "postal_code is the postal code used in a postal address";
                                        readonly type: "string";
                                    };
                                    readonly street_address: {
                                        readonly description: "The street name and mailbox number of a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly city: {
                                        readonly description: "The name of the city, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly state: {
                                        readonly description: "The name of the state or major region, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly country: {
                                        readonly description: "The name of the country, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly phone: {
                                readonly description: "phone describes the phone number with country code and area code.";
                                readonly type: "string";
                            };
                            readonly fax: {
                                readonly description: "fax number for a person or organization";
                                readonly type: "string";
                            };
                            readonly contact_type: {
                                readonly description: "Indicates if this particular contact person has some special role in the organization such as \"Food Safety Program Coordinator\" or \"Recall Coordinator.\"  Introduced for CanadaGAP Audit";
                                readonly type: "string";
                                readonly examples: readonly ["Food Safety Program Coordinator", "Recall Coordinator", "Responsible For Operation"];
                            };
                            readonly contact_types: {
                                readonly description: "Allows one person to be multiple contact types.  Introduced for CanadaGAP audits.";
                                readonly type: "array";
                                readonly items: {
                                    readonly description: "Indicates if this particular contact person has some special role in the organization such as \"Food Safety Program Coordinator\" or \"Recall Coordinator.\"  Introduced for CanadaGAP Audit";
                                    readonly type: "string";
                                    readonly examples: readonly ["Food Safety Program Coordinator", "Recall Coordinator", "Responsible For Operation"];
                                };
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly location: {
                    readonly description: "location describes the postal address used to identify where something is.";
                    readonly properties: {
                        readonly postal_code: {
                            readonly description: "postal_code is the postal code used in a postal address";
                            readonly type: "string";
                        };
                        readonly street_address: {
                            readonly description: "The street name and mailbox number of a postal address.";
                            readonly type: "string";
                        };
                        readonly city: {
                            readonly description: "The name of the city, usually in a postal address.";
                            readonly type: "string";
                        };
                        readonly state: {
                            readonly description: "The name of the state or major region, usually in a postal address.";
                            readonly type: "string";
                        };
                        readonly country: {
                            readonly description: "The name of the country, usually in a postal address.";
                            readonly type: "string";
                        };
                        readonly name: {
                            readonly description: "name is a string, typically the name of the object the key appears in.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                    };
                    readonly type: "object";
                };
                readonly phone: {
                    readonly description: "phone describes the phone number with country code and area code.";
                    readonly type: "string";
                };
                readonly fax: {
                    readonly description: "fax number for a person or organization";
                    readonly type: "string";
                };
                readonly orgchart: {
                    readonly description: "orgchart is a tricky one.  It is intended to represent the reporting structure within an organization.  Introduced for the CanadaGAP audit. It is a flat object with keys that represent the \"id\" of a person.  Each value in this outer object is a single person, and may have name, job_title, and job_description.  If this person reports to someone else, the reports_to key should be included in their object as well (an array of all the people they report to), thus creating a directed graph of relationships.";
                    readonly patternProperties: {
                        readonly '.*': {
                            readonly description: "An orgchart_person has all the possible properties of a person, but also can have job_title, job_description, and reports_to.";
                            readonly properties: {
                                readonly job_title: {
                                    readonly description: "The title of this person within their organization.";
                                    readonly type: "string";
                                };
                                readonly job_description: {
                                    readonly description: "A description of what this person does or is responsible for within an organization.";
                                    readonly type: "string";
                                };
                                readonly reports_to: {
                                    readonly description: "An array of all the ID strings of the people to whom this person reports";
                                    readonly type: "array";
                                    readonly items: {
                                        readonly description: "An id is a string which should be reasonably unique to represent the  object it belongs to.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                };
                            };
                            readonly type: "object";
                        };
                    };
                };
            };
            readonly required: readonly ["organizationid", "name"];
            readonly type: "object";
        };
        readonly scope: {
            readonly description: "scope describes the breadth of the audit in terms of operations, personnel, products, etc.";
            readonly properties: {
                readonly description: {
                    readonly description: "a string description of an object, usually longer than \"name\"";
                    readonly type: "string";
                };
                readonly notification: {
                    readonly description: "notification describes whether the target of the audit was notified in advance that this audit would take place.  \"announced\" or \"unannounced\".";
                    readonly type: "string";
                    readonly examples: readonly ["announced", "unannounced"];
                };
                readonly operation: {
                    readonly description: "an object describing the operation that is under audit. For GlobalGAP, this is just an object with a name.  For PrimusGFS, this is holds description";
                    readonly properties: {
                        readonly operation_type: {
                            readonly description: "type of a given operation";
                            readonly type: "string";
                            readonly examples: readonly ["harvest", "packinghouse", "cold storage", "growing", "handling", "u-pick", "storage", "packing - production site", "repacking", "brokerage", "wholesale"];
                        };
                        readonly operator: {
                            readonly description: "operator is used to detail the information about the crew or on-site operators for a given operation.";
                            readonly properties: {
                                readonly contacts: {
                                    readonly description: "contacts is a list of contact people for an organization.";
                                    readonly type: "array";
                                    readonly items: {
                                        readonly description: "contact describes an individuals who may be contacted in reference to this audit.";
                                        readonly properties: {
                                            readonly name: {
                                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                                readonly type: "string";
                                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                            };
                                            readonly email: {
                                                readonly description: "email address for an organization or contact";
                                                readonly type: "string";
                                            };
                                            readonly location: {
                                                readonly description: "location describes the postal address used to identify where something is.";
                                                readonly properties: {
                                                    readonly postal_code: {
                                                        readonly description: "postal_code is the postal code used in a postal address";
                                                        readonly type: "string";
                                                    };
                                                    readonly street_address: {
                                                        readonly description: "The street name and mailbox number of a postal address.";
                                                        readonly type: "string";
                                                    };
                                                    readonly city: {
                                                        readonly description: "The name of the city, usually in a postal address.";
                                                        readonly type: "string";
                                                    };
                                                    readonly state: {
                                                        readonly description: "The name of the state or major region, usually in a postal address.";
                                                        readonly type: "string";
                                                    };
                                                    readonly country: {
                                                        readonly description: "The name of the country, usually in a postal address.";
                                                        readonly type: "string";
                                                    };
                                                    readonly name: {
                                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                                        readonly type: "string";
                                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly phone: {
                                                readonly description: "phone describes the phone number with country code and area code.";
                                                readonly type: "string";
                                            };
                                            readonly fax: {
                                                readonly description: "fax number for a person or organization";
                                                readonly type: "string";
                                            };
                                            readonly contact_type: {
                                                readonly description: "Indicates if this particular contact person has some special role in the organization such as \"Food Safety Program Coordinator\" or \"Recall Coordinator.\"  Introduced for CanadaGAP Audit";
                                                readonly type: "string";
                                                readonly examples: readonly ["Food Safety Program Coordinator", "Recall Coordinator", "Responsible For Operation"];
                                            };
                                            readonly contact_types: {
                                                readonly description: "Allows one person to be multiple contact types.  Introduced for CanadaGAP audits.";
                                                readonly type: "array";
                                                readonly items: {
                                                    readonly description: "Indicates if this particular contact person has some special role in the organization such as \"Food Safety Program Coordinator\" or \"Recall Coordinator.\"  Introduced for CanadaGAP Audit";
                                                    readonly type: "string";
                                                    readonly examples: readonly ["Food Safety Program Coordinator", "Recall Coordinator", "Responsible For Operation"];
                                                };
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                };
                                readonly name: {
                                    readonly description: "name is a string, typically the name of the object the key appears in.";
                                    readonly type: "string";
                                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                };
                                readonly location: {
                                    readonly description: "location describes the postal address used to identify where something is.";
                                    readonly properties: {
                                        readonly postal_code: {
                                            readonly description: "postal_code is the postal code used in a postal address";
                                            readonly type: "string";
                                        };
                                        readonly street_address: {
                                            readonly description: "The street name and mailbox number of a postal address.";
                                            readonly type: "string";
                                        };
                                        readonly city: {
                                            readonly description: "The name of the city, usually in a postal address.";
                                            readonly type: "string";
                                        };
                                        readonly state: {
                                            readonly description: "The name of the state or major region, usually in a postal address.";
                                            readonly type: "string";
                                        };
                                        readonly country: {
                                            readonly description: "The name of the country, usually in a postal address.";
                                            readonly type: "string";
                                        };
                                        readonly name: {
                                            readonly description: "name is a string, typically the name of the object the key appears in.";
                                            readonly type: "string";
                                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                        };
                                    };
                                    readonly type: "object";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly shipper: {
                            readonly description: "shipper is the parent organization who will be responsible for moving the product(s) to their next destination.";
                            readonly properties: {
                                readonly name: {
                                    readonly description: "name is a string, typically the name of the object the key appears in.";
                                    readonly type: "string";
                                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly location: {
                            readonly description: "location describes the postal address used to identify where something is.";
                            readonly properties: {
                                readonly postal_code: {
                                    readonly description: "postal_code is the postal code used in a postal address";
                                    readonly type: "string";
                                };
                                readonly street_address: {
                                    readonly description: "The street name and mailbox number of a postal address.";
                                    readonly type: "string";
                                };
                                readonly city: {
                                    readonly description: "The name of the city, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly state: {
                                    readonly description: "The name of the state or major region, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly country: {
                                    readonly description: "The name of the country, usually in a postal address.";
                                    readonly type: "string";
                                };
                                readonly name: {
                                    readonly description: "name is a string, typically the name of the object the key appears in.";
                                    readonly type: "string";
                                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly name: {
                            readonly description: "name is a string, typically the name of the object the key appears in.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                    };
                    readonly type: "object";
                };
                readonly products_observed: {
                    readonly description: "The set of products evaluated in the audit.";
                    readonly type: "array";
                    readonly items: {
                        readonly description: "product describes the particular type of item being evaluated in the audit. May describe the fruit, vegetable, etc. as well as other descriptors such as \"chopped\", \"pitted\", \"organic\", etc.";
                        readonly properties: {
                            readonly name: {
                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                readonly examples: readonly ["tomatoes", "peppers", "zucchini"];
                            };
                            readonly organic: {
                                readonly description: "organic is a true/false value indicating if a particular product is considered organic or not.";
                                readonly type: "boolean";
                            };
                            readonly area: {
                                readonly description: "area describes a quantity of area such as acres or hectares.";
                                readonly properties: {
                                    readonly units: {
                                        readonly description: "the units used to interpret the associated value.";
                                        readonly type: "string";
                                        readonly examples: readonly ["acres", "ac", "hectares", "ha"];
                                    };
                                    readonly value: {
                                        readonly description: "a numeric or qualitative value, represented as a string";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly location: {
                                readonly description: "location describes the postal address used to identify where something is.";
                                readonly properties: {
                                    readonly postal_code: {
                                        readonly description: "postal_code is the postal code used in a postal address";
                                        readonly type: "string";
                                    };
                                    readonly street_address: {
                                        readonly description: "The street name and mailbox number of a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly city: {
                                        readonly description: "The name of the city, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly state: {
                                        readonly description: "The name of the state or major region, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly country: {
                                        readonly description: "The name of the country, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly similar_products_not_observed: {
                    readonly description: "array of products not under evaulation that may be similar to those observed in the audit.";
                    readonly type: "array";
                    readonly items: {
                        readonly description: "product describes the particular type of item being evaluated in the audit. May describe the fruit, vegetable, etc. as well as other descriptors such as \"chopped\", \"pitted\", \"organic\", etc.";
                        readonly properties: {
                            readonly name: {
                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                readonly examples: readonly ["tomatoes", "peppers", "zucchini"];
                            };
                            readonly organic: {
                                readonly description: "organic is a true/false value indicating if a particular product is considered organic or not.";
                                readonly type: "boolean";
                            };
                            readonly area: {
                                readonly description: "area describes a quantity of area such as acres or hectares.";
                                readonly properties: {
                                    readonly units: {
                                        readonly description: "the units used to interpret the associated value.";
                                        readonly type: "string";
                                        readonly examples: readonly ["acres", "ac", "hectares", "ha"];
                                    };
                                    readonly value: {
                                        readonly description: "a numeric or qualitative value, represented as a string";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly location: {
                                readonly description: "location describes the postal address used to identify where something is.";
                                readonly properties: {
                                    readonly postal_code: {
                                        readonly description: "postal_code is the postal code used in a postal address";
                                        readonly type: "string";
                                    };
                                    readonly street_address: {
                                        readonly description: "The street name and mailbox number of a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly city: {
                                        readonly description: "The name of the city, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly state: {
                                        readonly description: "The name of the state or major region, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly country: {
                                        readonly description: "The name of the country, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly products_applied_for_but_not_observed: {
                    readonly description: "array of products that had been applied for but are not under evaulation in this particular audit.";
                    readonly type: "array";
                    readonly items: {
                        readonly description: "product describes the particular type of item being evaluated in the audit. May describe the fruit, vegetable, etc. as well as other descriptors such as \"chopped\", \"pitted\", \"organic\", etc.";
                        readonly properties: {
                            readonly name: {
                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                readonly examples: readonly ["tomatoes", "peppers", "zucchini"];
                            };
                            readonly organic: {
                                readonly description: "organic is a true/false value indicating if a particular product is considered organic or not.";
                                readonly type: "boolean";
                            };
                            readonly area: {
                                readonly description: "area describes a quantity of area such as acres or hectares.";
                                readonly properties: {
                                    readonly units: {
                                        readonly description: "the units used to interpret the associated value.";
                                        readonly type: "string";
                                        readonly examples: readonly ["acres", "ac", "hectares", "ha"];
                                    };
                                    readonly value: {
                                        readonly description: "a numeric or qualitative value, represented as a string";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly location: {
                                readonly description: "location describes the postal address used to identify where something is.";
                                readonly properties: {
                                    readonly postal_code: {
                                        readonly description: "postal_code is the postal code used in a postal address";
                                        readonly type: "string";
                                    };
                                    readonly street_address: {
                                        readonly description: "The street name and mailbox number of a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly city: {
                                        readonly description: "The name of the city, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly state: {
                                        readonly description: "The name of the state or major region, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly country: {
                                        readonly description: "The name of the country, usually in a postal address.";
                                        readonly type: "string";
                                    };
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly production_sites: {
                    readonly description: "production_sites is an array of object, each of which are a production site.";
                    readonly items: {
                        readonly description: "A production_site is defined for GlobalGAP and describes the products grown, harvested, or handled at multiple locations for the same audit.";
                        readonly properties: {
                            readonly name: {
                                readonly description: "name is a string, typically the name of the object the key appears in.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                            };
                            readonly id: {
                                readonly description: "An id is a string which should be reasonably unique to represent the  object it belongs to.";
                                readonly type: "string";
                                readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                            };
                            readonly products_observed: {
                                readonly description: "The set of products evaluated in the audit.";
                                readonly type: "array";
                                readonly items: {
                                    readonly description: "product describes the particular type of item being evaluated in the audit. May describe the fruit, vegetable, etc. as well as other descriptors such as \"chopped\", \"pitted\", \"organic\", etc.";
                                    readonly properties: {
                                        readonly name: {
                                            readonly description: "name is a string, typically the name of the object the key appears in.";
                                            readonly type: "string";
                                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                            readonly examples: readonly ["tomatoes", "peppers", "zucchini"];
                                        };
                                        readonly organic: {
                                            readonly description: "organic is a true/false value indicating if a particular product is considered organic or not.";
                                            readonly type: "boolean";
                                        };
                                        readonly area: {
                                            readonly description: "area describes a quantity of area such as acres or hectares.";
                                            readonly properties: {
                                                readonly units: {
                                                    readonly description: "the units used to interpret the associated value.";
                                                    readonly type: "string";
                                                    readonly examples: readonly ["acres", "ac", "hectares", "ha"];
                                                };
                                                readonly value: {
                                                    readonly description: "a numeric or qualitative value, represented as a string";
                                                    readonly type: "string";
                                                };
                                            };
                                            readonly type: "object";
                                        };
                                        readonly location: {
                                            readonly description: "location describes the postal address used to identify where something is.";
                                            readonly properties: {
                                                readonly postal_code: {
                                                    readonly description: "postal_code is the postal code used in a postal address";
                                                    readonly type: "string";
                                                };
                                                readonly street_address: {
                                                    readonly description: "The street name and mailbox number of a postal address.";
                                                    readonly type: "string";
                                                };
                                                readonly city: {
                                                    readonly description: "The name of the city, usually in a postal address.";
                                                    readonly type: "string";
                                                };
                                                readonly state: {
                                                    readonly description: "The name of the state or major region, usually in a postal address.";
                                                    readonly type: "string";
                                                };
                                                readonly country: {
                                                    readonly description: "The name of the country, usually in a postal address.";
                                                    readonly type: "string";
                                                };
                                                readonly name: {
                                                    readonly description: "name is a string, typically the name of the object the key appears in.";
                                                    readonly type: "string";
                                                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                                };
                                            };
                                            readonly type: "object";
                                        };
                                    };
                                    readonly type: "object";
                                };
                            };
                        };
                        readonly type: "object";
                    };
                };
                readonly parallel_production: {
                    readonly description: "parallel_production is defined for GlobalGAP as to whether the site is growing other things in addition to those under audit.";
                    readonly type: "boolean";
                };
                readonly parallel_ownership: {
                    readonly description: "parallel_ownership is defined for GlobalGAP as to whether the site is growing things owned by someone other than the party under audit";
                    readonly type: "boolean";
                };
                readonly applicable_sites_description: {
                    readonly description: "Introduced for CanadaGAP, this holds a free-form string describing which  types of sites this audit applies to.";
                    readonly type: "string";
                };
            };
            readonly required: readonly ["notification", "description", "operations", "products_observed"];
            readonly type: "object";
        };
        readonly conditions_during_audit: {
            readonly description: "describes conditions when the audit took place.  Date audit started/finished, etc.";
            readonly properties: {
                readonly FSMS_observed_date: {
                    readonly description: "the period (beginning and ending times) of the FSMS portion of the audit.";
                    readonly properties: {
                        readonly start: {
                            readonly description: "start describes the date and time when the audit started";
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}-[0-9]{2}-[0-9]{2}$";
                        };
                        readonly end: {
                            readonly description: "end describes the date and time when the audit was completed.";
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}-[0-9]{2}-[0-9]{2}$";
                        };
                        readonly duration: {
                            readonly description: "duration describes how long an audit took to perform.  Introduced for GlobalGAP audits since that is how they specify it instead of start/end.";
                            readonly properties: {
                                readonly units: {
                                    readonly description: "the units used to interpret the associated value.";
                                    readonly type: "string";
                                    readonly examples: readonly ["hours"];
                                };
                                readonly value: {
                                    readonly description: "a numeric or qualitative value, represented as a string";
                                    readonly type: "string";
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly required: readonly ["start", "end"];
                    readonly type: "object";
                };
                readonly operation_observed_date: {
                    readonly description: "the period (beginning and ending times) of the walk-through/field operations portion of the audit.";
                    readonly properties: {
                        readonly start: {
                            readonly description: "start describes the date and time when the audit started";
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}-[0-9]{2}-[0-9]{2}$";
                        };
                        readonly end: {
                            readonly description: "end describes the date and time when the audit was completed.";
                            readonly type: "string";
                            readonly pattern: "^[0-9]{4}-[0-9]{2}-[0-9]{2}$";
                        };
                        readonly duration: {
                            readonly description: "duration describes how long an audit took to perform.  Introduced for GlobalGAP audits since that is how they specify it instead of start/end.";
                            readonly properties: {
                                readonly units: {
                                    readonly description: "the units used to interpret the associated value.";
                                    readonly type: "string";
                                    readonly examples: readonly ["hours"];
                                };
                                readonly value: {
                                    readonly description: "a numeric or qualitative value, represented as a string";
                                    readonly type: "string";
                                };
                            };
                            readonly type: "object";
                        };
                    };
                    readonly required: readonly ["start", "end"];
                    readonly type: "object";
                };
            };
            readonly required: readonly ["FSMS_observed_date", "operation_observed_date"];
            readonly type: "object";
        };
        readonly certificationid: {
            readonly description: "certificationid is an id which spans all documents for a single certification process.  i.e. the audit, corrective actions, and final certificate all share the same certificationid";
            readonly properties: {
                readonly id: {
                    readonly description: "An id is a string which should be reasonably unique to represent the  object it belongs to.";
                    readonly type: "string";
                    readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                };
                readonly id_source: {
                    readonly description: "An id_source is a representation of who assigned the id: i.e. who do you go ask to figure out what a particular ID goes to.";
                    readonly type: "string";
                    readonly examples: readonly ["scheme", "certifying_body"];
                };
            };
            readonly type: "object";
        };
        readonly score: {
            readonly description: "score presents the quanititative performance of a control point, section, or overall audit.";
            readonly properties: {
                readonly units: {
                    readonly description: "the units used to interpret the associated value.";
                    readonly type: "string";
                };
                readonly preliminary: {
                    readonly description: "A prelimiary score for an audit";
                    readonly properties: {
                        readonly value: {
                            readonly description: "a numeric or qualitative value, represented as a string";
                            readonly type: "string";
                        };
                        readonly units: {
                            readonly description: "the units used to interpret the associated value.";
                            readonly type: "string";
                        };
                        readonly possible: {
                            readonly description: "Number of points possible for this control point";
                            readonly type: "string";
                        };
                    };
                    readonly type: "object";
                };
                readonly final: {
                    readonly description: "The final score for an audit";
                    readonly properties: {
                        readonly value: {
                            readonly description: "a numeric or qualitative value, represented as a string";
                            readonly type: "string";
                        };
                        readonly units: {
                            readonly description: "the units used to interpret the associated value.";
                            readonly type: "string";
                        };
                        readonly possible: {
                            readonly description: "Number of points possible for this control point";
                            readonly type: "string";
                        };
                    };
                    readonly type: "object";
                };
                readonly value: {
                    readonly description: "a numeric or qualitative value, represented as a string";
                    readonly type: "string";
                };
                readonly possible: {
                    readonly description: "Number of points possible for this control point";
                    readonly type: "string";
                };
                readonly compliance: {
                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                    readonly type: "string";
                };
                readonly globalgap_levels: {
                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                    readonly properties: {
                        readonly major_musts: {
                            readonly description: "The summary score for all major-must level questions";
                            readonly anyOf: readonly [{
                                readonly properties: {
                                    readonly yes: {
                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly no: {
                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly n_a: {
                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly is_compliant: {
                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                        readonly type: "boolean";
                                    };
                                };
                                readonly type: "object";
                            }, {
                                readonly properties: {
                                    readonly major_must: {
                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly minor_must: {
                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly recommended: {
                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                };
                                readonly type: "object";
                            }];
                        };
                        readonly minor_musts: {
                            readonly description: "The summary score for all minor-must level questions";
                            readonly anyOf: readonly [{
                                readonly properties: {
                                    readonly yes: {
                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly no: {
                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly n_a: {
                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly is_compliant: {
                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                        readonly type: "boolean";
                                    };
                                };
                                readonly type: "object";
                            }, {
                                readonly properties: {
                                    readonly major_must: {
                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly minor_must: {
                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly recommended: {
                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                        readonly properties: {
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                                readonly examples: readonly ["count"];
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                };
                                readonly type: "object";
                            }];
                        };
                    };
                    readonly type: "object";
                };
                readonly canadagap_isautofail: {
                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                    readonly type: "boolean";
                };
                readonly subtotals: {
                    readonly description: "Introduced for CanadaGAP.  Represents the sub totals for various combinations of sections as specified by CanadaGAP, as well as the weighting_factor for that combination of sections toward the overall score.  This is needed because the subtotals do not perfectly match the sections, so it exists here as a separate key.  Other audits should just put the subtotal under the section that it goes with.";
                    readonly properties: {
                        readonly score: {
                            readonly description: "Do not use score_core in an audit schema.  It exists to avoid recursive definition of score and subtotals.";
                            readonly properties: {
                                readonly units: {
                                    readonly description: "the units used to interpret the associated value.";
                                    readonly type: "string";
                                };
                                readonly preliminary: {
                                    readonly description: "A prelimiary score for an audit";
                                    readonly properties: {
                                        readonly value: {
                                            readonly description: "a numeric or qualitative value, represented as a string";
                                            readonly type: "string";
                                        };
                                        readonly units: {
                                            readonly description: "the units used to interpret the associated value.";
                                            readonly type: "string";
                                        };
                                        readonly possible: {
                                            readonly description: "Number of points possible for this control point";
                                            readonly type: "string";
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly final: {
                                    readonly description: "The final score for an audit";
                                    readonly properties: {
                                        readonly value: {
                                            readonly description: "a numeric or qualitative value, represented as a string";
                                            readonly type: "string";
                                        };
                                        readonly units: {
                                            readonly description: "the units used to interpret the associated value.";
                                            readonly type: "string";
                                        };
                                        readonly possible: {
                                            readonly description: "Number of points possible for this control point";
                                            readonly type: "string";
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly value: {
                                    readonly description: "a numeric or qualitative value, represented as a string";
                                    readonly type: "string";
                                };
                                readonly possible: {
                                    readonly description: "Number of points possible for this control point";
                                    readonly type: "string";
                                };
                                readonly compliance: {
                                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                    readonly type: "string";
                                };
                                readonly globalgap_levels: {
                                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                    readonly properties: {
                                        readonly major_musts: {
                                            readonly description: "The summary score for all major-must level questions";
                                            readonly anyOf: readonly [{
                                                readonly properties: {
                                                    readonly yes: {
                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly no: {
                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly n_a: {
                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly is_compliant: {
                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                        readonly type: "boolean";
                                                    };
                                                };
                                                readonly type: "object";
                                            }, {
                                                readonly properties: {
                                                    readonly major_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly minor_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly recommended: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                };
                                                readonly type: "object";
                                            }];
                                        };
                                        readonly minor_musts: {
                                            readonly description: "The summary score for all minor-must level questions";
                                            readonly anyOf: readonly [{
                                                readonly properties: {
                                                    readonly yes: {
                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly no: {
                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly n_a: {
                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly is_compliant: {
                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                        readonly type: "boolean";
                                                    };
                                                };
                                                readonly type: "object";
                                            }, {
                                                readonly properties: {
                                                    readonly major_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly minor_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly recommended: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                };
                                                readonly type: "object";
                                            }];
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly canadagap_isautofail: {
                                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                    readonly type: "boolean";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly name: {
                            readonly description: "name is a string, typically the name of the object the key appears in.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                        readonly sectionids: {
                            readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                            readonly type: "array";
                            readonly items: {
                                readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                                readonly type: "string";
                            };
                        };
                        readonly weighting_factor: {
                            readonly description: "Introduced for CanadaGAP.  Represents the weight used to combine sections into a total score.";
                            readonly type: "string";
                            readonly pattern: "^-?[0-9]+(.[0-9]+)?";
                        };
                    };
                    readonly type: "object";
                };
            };
            readonly type: "object";
        };
        readonly sections: {
            readonly description: "sections is a list of section objects, used for organizing control points into groupings.";
            readonly type: "array";
            readonly items: {
                readonly description: "A section is a recursively defined partition of the audit, meaning that it may contain other \"child\" sections within it.  If it is a specialized sub-section that does not follow a clean hierarchy, it may use the sectionids key to state which other sections belong to this section.  Introduced the sectionids for CanadaGAP to handle the sub-total sections of A1-3 and A4-5.";
                readonly properties: {
                    readonly sections: {};
                    readonly name: {
                        readonly description: "name is a string, typically the name of the object the key appears in.";
                        readonly type: "string";
                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                    };
                    readonly sectionid: {
                        readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                        readonly type: "string";
                    };
                    readonly score: {
                        readonly description: "score presents the quanititative performance of a control point, section, or overall audit.";
                        readonly properties: {
                            readonly units: {
                                readonly description: "the units used to interpret the associated value.";
                                readonly type: "string";
                            };
                            readonly preliminary: {
                                readonly description: "A prelimiary score for an audit";
                                readonly properties: {
                                    readonly value: {
                                        readonly description: "a numeric or qualitative value, represented as a string";
                                        readonly type: "string";
                                    };
                                    readonly units: {
                                        readonly description: "the units used to interpret the associated value.";
                                        readonly type: "string";
                                    };
                                    readonly possible: {
                                        readonly description: "Number of points possible for this control point";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly final: {
                                readonly description: "The final score for an audit";
                                readonly properties: {
                                    readonly value: {
                                        readonly description: "a numeric or qualitative value, represented as a string";
                                        readonly type: "string";
                                    };
                                    readonly units: {
                                        readonly description: "the units used to interpret the associated value.";
                                        readonly type: "string";
                                    };
                                    readonly possible: {
                                        readonly description: "Number of points possible for this control point";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly value: {
                                readonly description: "a numeric or qualitative value, represented as a string";
                                readonly type: "string";
                            };
                            readonly possible: {
                                readonly description: "Number of points possible for this control point";
                                readonly type: "string";
                            };
                            readonly compliance: {
                                readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                readonly type: "string";
                            };
                            readonly globalgap_levels: {
                                readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                readonly properties: {
                                    readonly major_musts: {
                                        readonly description: "The summary score for all major-must level questions";
                                        readonly anyOf: readonly [{
                                            readonly properties: {
                                                readonly yes: {
                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly no: {
                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly n_a: {
                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly is_compliant: {
                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                    readonly type: "boolean";
                                                };
                                            };
                                            readonly type: "object";
                                        }, {
                                            readonly properties: {
                                                readonly major_must: {
                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly minor_must: {
                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly recommended: {
                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                            };
                                            readonly type: "object";
                                        }];
                                    };
                                    readonly minor_musts: {
                                        readonly description: "The summary score for all minor-must level questions";
                                        readonly anyOf: readonly [{
                                            readonly properties: {
                                                readonly yes: {
                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly no: {
                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly n_a: {
                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly is_compliant: {
                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                    readonly type: "boolean";
                                                };
                                            };
                                            readonly type: "object";
                                        }, {
                                            readonly properties: {
                                                readonly major_must: {
                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly minor_must: {
                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly recommended: {
                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                            readonly examples: readonly ["count"];
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                            };
                                            readonly type: "object";
                                        }];
                                    };
                                };
                                readonly type: "object";
                            };
                            readonly canadagap_isautofail: {
                                readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                readonly type: "boolean";
                            };
                            readonly subtotals: {
                                readonly description: "Introduced for CanadaGAP.  Represents the sub totals for various combinations of sections as specified by CanadaGAP, as well as the weighting_factor for that combination of sections toward the overall score.  This is needed because the subtotals do not perfectly match the sections, so it exists here as a separate key.  Other audits should just put the subtotal under the section that it goes with.";
                                readonly properties: {
                                    readonly score: {
                                        readonly description: "Do not use score_core in an audit schema.  It exists to avoid recursive definition of score and subtotals.";
                                        readonly properties: {
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                            };
                                            readonly preliminary: {
                                                readonly description: "A prelimiary score for an audit";
                                                readonly properties: {
                                                    readonly value: {
                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                        readonly type: "string";
                                                    };
                                                    readonly units: {
                                                        readonly description: "the units used to interpret the associated value.";
                                                        readonly type: "string";
                                                    };
                                                    readonly possible: {
                                                        readonly description: "Number of points possible for this control point";
                                                        readonly type: "string";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly final: {
                                                readonly description: "The final score for an audit";
                                                readonly properties: {
                                                    readonly value: {
                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                        readonly type: "string";
                                                    };
                                                    readonly units: {
                                                        readonly description: "the units used to interpret the associated value.";
                                                        readonly type: "string";
                                                    };
                                                    readonly possible: {
                                                        readonly description: "Number of points possible for this control point";
                                                        readonly type: "string";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                            readonly compliance: {
                                                readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                readonly type: "string";
                                            };
                                            readonly globalgap_levels: {
                                                readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                readonly properties: {
                                                    readonly major_musts: {
                                                        readonly description: "The summary score for all major-must level questions";
                                                        readonly anyOf: readonly [{
                                                            readonly properties: {
                                                                readonly yes: {
                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly no: {
                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly n_a: {
                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly is_compliant: {
                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                    readonly type: "boolean";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }, {
                                                            readonly properties: {
                                                                readonly major_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly minor_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly recommended: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }];
                                                    };
                                                    readonly minor_musts: {
                                                        readonly description: "The summary score for all minor-must level questions";
                                                        readonly anyOf: readonly [{
                                                            readonly properties: {
                                                                readonly yes: {
                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly no: {
                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly n_a: {
                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly is_compliant: {
                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                    readonly type: "boolean";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }, {
                                                            readonly properties: {
                                                                readonly major_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly minor_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly recommended: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }];
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly canadagap_isautofail: {
                                                readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                readonly type: "boolean";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                    readonly sectionids: {
                                        readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                                        readonly type: "array";
                                        readonly items: {
                                            readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                                            readonly type: "string";
                                        };
                                    };
                                    readonly weighting_factor: {
                                        readonly description: "Introduced for CanadaGAP.  Represents the weight used to combine sections into a total score.";
                                        readonly type: "string";
                                        readonly pattern: "^-?[0-9]+(.[0-9]+)?";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                        readonly type: "object";
                    };
                    readonly sectionids: {
                        readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                        readonly type: "array";
                        readonly items: {
                            readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                            readonly type: "string";
                        };
                    };
                    readonly control_pointids: {
                        readonly description: "control_pointids lists the array of control point ids associated with the given section.";
                        readonly type: "array";
                        readonly items: {
                            readonly description: "control_pointid is the id associated with a particular control point.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                    };
                    readonly supporting_points: {
                        readonly description: "supporting_points is just an object whose keys are supporting_pointids, and whose values are supporting_point objects.";
                        readonly patternProperties: {
                            readonly '^(?!(indexing|.*-index|_.*)).*$': {
                                readonly description: "A supporting point is a sub-point within a control point.  This was introduced for CanadaGAP to represent all the checkboxes under the control points.  It is just an object with a name and a score.";
                                readonly properties: {
                                    readonly name: {
                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                        readonly type: "string";
                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                    };
                                    readonly score: {
                                        readonly description: "score presents the quanititative performance of a control point, section, or overall audit.";
                                        readonly properties: {
                                            readonly units: {
                                                readonly description: "the units used to interpret the associated value.";
                                                readonly type: "string";
                                            };
                                            readonly preliminary: {
                                                readonly description: "A prelimiary score for an audit";
                                                readonly properties: {
                                                    readonly value: {
                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                        readonly type: "string";
                                                    };
                                                    readonly units: {
                                                        readonly description: "the units used to interpret the associated value.";
                                                        readonly type: "string";
                                                    };
                                                    readonly possible: {
                                                        readonly description: "Number of points possible for this control point";
                                                        readonly type: "string";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly final: {
                                                readonly description: "The final score for an audit";
                                                readonly properties: {
                                                    readonly value: {
                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                        readonly type: "string";
                                                    };
                                                    readonly units: {
                                                        readonly description: "the units used to interpret the associated value.";
                                                        readonly type: "string";
                                                    };
                                                    readonly possible: {
                                                        readonly description: "Number of points possible for this control point";
                                                        readonly type: "string";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly value: {
                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                readonly type: "string";
                                            };
                                            readonly possible: {
                                                readonly description: "Number of points possible for this control point";
                                                readonly type: "string";
                                            };
                                            readonly compliance: {
                                                readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                readonly type: "string";
                                            };
                                            readonly globalgap_levels: {
                                                readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                readonly properties: {
                                                    readonly major_musts: {
                                                        readonly description: "The summary score for all major-must level questions";
                                                        readonly anyOf: readonly [{
                                                            readonly properties: {
                                                                readonly yes: {
                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly no: {
                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly n_a: {
                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly is_compliant: {
                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                    readonly type: "boolean";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }, {
                                                            readonly properties: {
                                                                readonly major_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly minor_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly recommended: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }];
                                                    };
                                                    readonly minor_musts: {
                                                        readonly description: "The summary score for all minor-must level questions";
                                                        readonly anyOf: readonly [{
                                                            readonly properties: {
                                                                readonly yes: {
                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly no: {
                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly n_a: {
                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly is_compliant: {
                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                    readonly type: "boolean";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }, {
                                                            readonly properties: {
                                                                readonly major_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly minor_must: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly recommended: {
                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                            readonly examples: readonly ["count"];
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        }];
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                            readonly canadagap_isautofail: {
                                                readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                readonly type: "boolean";
                                            };
                                            readonly subtotals: {
                                                readonly description: "Introduced for CanadaGAP.  Represents the sub totals for various combinations of sections as specified by CanadaGAP, as well as the weighting_factor for that combination of sections toward the overall score.  This is needed because the subtotals do not perfectly match the sections, so it exists here as a separate key.  Other audits should just put the subtotal under the section that it goes with.";
                                                readonly properties: {
                                                    readonly score: {
                                                        readonly description: "Do not use score_core in an audit schema.  It exists to avoid recursive definition of score and subtotals.";
                                                        readonly properties: {
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                            };
                                                            readonly preliminary: {
                                                                readonly description: "A prelimiary score for an audit";
                                                                readonly properties: {
                                                                    readonly value: {
                                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                                        readonly type: "string";
                                                                    };
                                                                    readonly units: {
                                                                        readonly description: "the units used to interpret the associated value.";
                                                                        readonly type: "string";
                                                                    };
                                                                    readonly possible: {
                                                                        readonly description: "Number of points possible for this control point";
                                                                        readonly type: "string";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            };
                                                            readonly final: {
                                                                readonly description: "The final score for an audit";
                                                                readonly properties: {
                                                                    readonly value: {
                                                                        readonly description: "a numeric or qualitative value, represented as a string";
                                                                        readonly type: "string";
                                                                    };
                                                                    readonly units: {
                                                                        readonly description: "the units used to interpret the associated value.";
                                                                        readonly type: "string";
                                                                    };
                                                                    readonly possible: {
                                                                        readonly description: "Number of points possible for this control point";
                                                                        readonly type: "string";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            };
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                            readonly compliance: {
                                                                readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                                readonly type: "string";
                                                            };
                                                            readonly globalgap_levels: {
                                                                readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                                readonly properties: {
                                                                    readonly major_musts: {
                                                                        readonly description: "The summary score for all major-must level questions";
                                                                        readonly anyOf: readonly [{
                                                                            readonly properties: {
                                                                                readonly yes: {
                                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly no: {
                                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly n_a: {
                                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly is_compliant: {
                                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                                    readonly type: "boolean";
                                                                                };
                                                                            };
                                                                            readonly type: "object";
                                                                        }, {
                                                                            readonly properties: {
                                                                                readonly major_must: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly minor_must: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly recommended: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                            };
                                                                            readonly type: "object";
                                                                        }];
                                                                    };
                                                                    readonly minor_musts: {
                                                                        readonly description: "The summary score for all minor-must level questions";
                                                                        readonly anyOf: readonly [{
                                                                            readonly properties: {
                                                                                readonly yes: {
                                                                                    readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly no: {
                                                                                    readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly n_a: {
                                                                                    readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly is_compliant: {
                                                                                    readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                                    readonly type: "boolean";
                                                                                };
                                                                            };
                                                                            readonly type: "object";
                                                                        }, {
                                                                            readonly properties: {
                                                                                readonly major_must: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly minor_must: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                                readonly recommended: {
                                                                                    readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                    readonly properties: {
                                                                                        readonly value: {
                                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                        readonly units: {
                                                                                            readonly description: "the units used to interpret the associated value.";
                                                                                            readonly type: "string";
                                                                                            readonly examples: readonly ["count"];
                                                                                        };
                                                                                        readonly possible: {
                                                                                            readonly description: "Number of points possible for this control point";
                                                                                            readonly type: "string";
                                                                                        };
                                                                                    };
                                                                                    readonly type: "object";
                                                                                };
                                                                            };
                                                                            readonly type: "object";
                                                                        }];
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            };
                                                            readonly canadagap_isautofail: {
                                                                readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                                readonly type: "boolean";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly name: {
                                                        readonly description: "name is a string, typically the name of the object the key appears in.";
                                                        readonly type: "string";
                                                        readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                                    };
                                                    readonly sectionids: {
                                                        readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                                                        readonly type: "array";
                                                        readonly items: {
                                                            readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly weighting_factor: {
                                                        readonly description: "Introduced for CanadaGAP.  Represents the weight used to combine sections into a total score.";
                                                        readonly type: "string";
                                                        readonly pattern: "^-?[0-9]+(.[0-9]+)?";
                                                    };
                                                };
                                                readonly type: "object";
                                            };
                                        };
                                        readonly type: "object";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                    };
                    readonly auditor_comments: {
                        readonly description: "Free-form text comments from the auditor for a particular control point or section.";
                        readonly type: "string";
                        readonly pattern: ".*";
                    };
                };
                readonly type: "object";
            };
        };
        readonly control_points: {
            readonly description: "control_points is a key that contains the complete set of control points within an audit. Each control point is indexed by its control_pointid. This key is a top level key for ease of accessing any/all control points. No prior knowledge of section structure is therefore necessary to look up a particular control point of interest.";
            readonly patternProperties: {
                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                    readonly description: "control_point is a single question/item to be addressed by the auditor and represents the core set of scores which are used for the audit.";
                    readonly properties: {
                        readonly name: {
                            readonly description: "name is a string, typically the name of the object the key appears in.";
                            readonly type: "string";
                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                        };
                        readonly score: {
                            readonly description: "score presents the quanititative performance of a control point, section, or overall audit.";
                            readonly properties: {
                                readonly units: {
                                    readonly description: "the units used to interpret the associated value.";
                                    readonly type: "string";
                                };
                                readonly preliminary: {
                                    readonly description: "A prelimiary score for an audit";
                                    readonly properties: {
                                        readonly value: {
                                            readonly description: "a numeric or qualitative value, represented as a string";
                                            readonly type: "string";
                                        };
                                        readonly units: {
                                            readonly description: "the units used to interpret the associated value.";
                                            readonly type: "string";
                                        };
                                        readonly possible: {
                                            readonly description: "Number of points possible for this control point";
                                            readonly type: "string";
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly final: {
                                    readonly description: "The final score for an audit";
                                    readonly properties: {
                                        readonly value: {
                                            readonly description: "a numeric or qualitative value, represented as a string";
                                            readonly type: "string";
                                        };
                                        readonly units: {
                                            readonly description: "the units used to interpret the associated value.";
                                            readonly type: "string";
                                        };
                                        readonly possible: {
                                            readonly description: "Number of points possible for this control point";
                                            readonly type: "string";
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly value: {
                                    readonly description: "a numeric or qualitative value, represented as a string";
                                    readonly type: "string";
                                };
                                readonly possible: {
                                    readonly description: "Number of points possible for this control point";
                                    readonly type: "string";
                                };
                                readonly compliance: {
                                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                    readonly type: "string";
                                };
                                readonly globalgap_levels: {
                                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                    readonly properties: {
                                        readonly major_musts: {
                                            readonly description: "The summary score for all major-must level questions";
                                            readonly anyOf: readonly [{
                                                readonly properties: {
                                                    readonly yes: {
                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly no: {
                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly n_a: {
                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly is_compliant: {
                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                        readonly type: "boolean";
                                                    };
                                                };
                                                readonly type: "object";
                                            }, {
                                                readonly properties: {
                                                    readonly major_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly minor_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly recommended: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                };
                                                readonly type: "object";
                                            }];
                                        };
                                        readonly minor_musts: {
                                            readonly description: "The summary score for all minor-must level questions";
                                            readonly anyOf: readonly [{
                                                readonly properties: {
                                                    readonly yes: {
                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly no: {
                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly n_a: {
                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly is_compliant: {
                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                        readonly type: "boolean";
                                                    };
                                                };
                                                readonly type: "object";
                                            }, {
                                                readonly properties: {
                                                    readonly major_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly minor_must: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                    readonly recommended: {
                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                        readonly properties: {
                                                            readonly value: {
                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                readonly type: "string";
                                                            };
                                                            readonly units: {
                                                                readonly description: "the units used to interpret the associated value.";
                                                                readonly type: "string";
                                                                readonly examples: readonly ["count"];
                                                            };
                                                            readonly possible: {
                                                                readonly description: "Number of points possible for this control point";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly type: "object";
                                                    };
                                                };
                                                readonly type: "object";
                                            }];
                                        };
                                    };
                                    readonly type: "object";
                                };
                                readonly canadagap_isautofail: {
                                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                    readonly type: "boolean";
                                };
                                readonly subtotals: {
                                    readonly description: "Introduced for CanadaGAP.  Represents the sub totals for various combinations of sections as specified by CanadaGAP, as well as the weighting_factor for that combination of sections toward the overall score.  This is needed because the subtotals do not perfectly match the sections, so it exists here as a separate key.  Other audits should just put the subtotal under the section that it goes with.";
                                    readonly properties: {
                                        readonly score: {
                                            readonly description: "Do not use score_core in an audit schema.  It exists to avoid recursive definition of score and subtotals.";
                                            readonly properties: {
                                                readonly units: {
                                                    readonly description: "the units used to interpret the associated value.";
                                                    readonly type: "string";
                                                };
                                                readonly preliminary: {
                                                    readonly description: "A prelimiary score for an audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly final: {
                                                    readonly description: "The final score for an audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly value: {
                                                    readonly description: "a numeric or qualitative value, represented as a string";
                                                    readonly type: "string";
                                                };
                                                readonly possible: {
                                                    readonly description: "Number of points possible for this control point";
                                                    readonly type: "string";
                                                };
                                                readonly compliance: {
                                                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                    readonly type: "string";
                                                };
                                                readonly globalgap_levels: {
                                                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                    readonly properties: {
                                                        readonly major_musts: {
                                                            readonly description: "The summary score for all major-must level questions";
                                                            readonly anyOf: readonly [{
                                                                readonly properties: {
                                                                    readonly yes: {
                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly no: {
                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly n_a: {
                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly is_compliant: {
                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                        readonly type: "boolean";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }, {
                                                                readonly properties: {
                                                                    readonly major_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly minor_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly recommended: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }];
                                                        };
                                                        readonly minor_musts: {
                                                            readonly description: "The summary score for all minor-must level questions";
                                                            readonly anyOf: readonly [{
                                                                readonly properties: {
                                                                    readonly yes: {
                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly no: {
                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly n_a: {
                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly is_compliant: {
                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                        readonly type: "boolean";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }, {
                                                                readonly properties: {
                                                                    readonly major_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly minor_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly recommended: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }];
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly canadagap_isautofail: {
                                                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                    readonly type: "boolean";
                                                };
                                            };
                                            readonly type: "object";
                                        };
                                        readonly name: {
                                            readonly description: "name is a string, typically the name of the object the key appears in.";
                                            readonly type: "string";
                                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                        };
                                        readonly sectionids: {
                                            readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                                            readonly type: "array";
                                            readonly items: {
                                                readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                                                readonly type: "string";
                                            };
                                        };
                                        readonly weighting_factor: {
                                            readonly description: "Introduced for CanadaGAP.  Represents the weight used to combine sections into a total score.";
                                            readonly type: "string";
                                            readonly pattern: "^-?[0-9]+(.[0-9]+)?";
                                        };
                                    };
                                    readonly type: "object";
                                };
                            };
                            readonly type: "object";
                        };
                        readonly comments: {
                            readonly description: "comments from an auditor on a particular control point";
                            readonly type: "string";
                        };
                        readonly files: {
                            readonly description: "a list of file URL's that go with a particular control point";
                            readonly type: "array";
                            readonly items: {
                                readonly description: "an object with a url at the moment, perhaps more complex later.";
                                readonly properties: {
                                    readonly url: {
                                        readonly description: "a string representing a URL link";
                                        readonly type: "string";
                                    };
                                };
                                readonly type: "object";
                            };
                        };
                        readonly justification: {
                            readonly description: "justification is an explanation by the auditor of why they scored a control_point the way they did";
                            readonly type: "string";
                        };
                        readonly criteria: {
                            readonly description: "criteria is an arrray of strings representing the various criteria needed for the certifying body to pass/fail a given control point";
                            readonly items: {
                                readonly type: "string";
                            };
                        };
                        readonly globalgap_level: {
                            readonly description: "globalgap_level is not actually a key that is used, but rather describes a class of objects which represent a level's summary score";
                            readonly enum: readonly ["major_must", "minor_must", "recommended"];
                        };
                        readonly auditor_comments: {
                            readonly description: "Free-form text comments from the auditor for a particular control point or section.";
                            readonly type: "string";
                            readonly pattern: ".*";
                        };
                        readonly supporting_points: {
                            readonly description: "supporting_points is just an object whose keys are supporting_pointids, and whose values are supporting_point objects.";
                            readonly patternProperties: {
                                readonly '^(?!(indexing|.*-index|_.*)).*$': {
                                    readonly description: "A supporting point is a sub-point within a control point.  This was introduced for CanadaGAP to represent all the checkboxes under the control points.  It is just an object with a name and a score.";
                                    readonly properties: {
                                        readonly name: {
                                            readonly description: "name is a string, typically the name of the object the key appears in.";
                                            readonly type: "string";
                                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                        };
                                        readonly score: {
                                            readonly description: "score presents the quanititative performance of a control point, section, or overall audit.";
                                            readonly properties: {
                                                readonly units: {
                                                    readonly description: "the units used to interpret the associated value.";
                                                    readonly type: "string";
                                                };
                                                readonly preliminary: {
                                                    readonly description: "A prelimiary score for an audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly final: {
                                                    readonly description: "The final score for an audit";
                                                    readonly properties: {
                                                        readonly value: {
                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                            readonly type: "string";
                                                        };
                                                        readonly units: {
                                                            readonly description: "the units used to interpret the associated value.";
                                                            readonly type: "string";
                                                        };
                                                        readonly possible: {
                                                            readonly description: "Number of points possible for this control point";
                                                            readonly type: "string";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly value: {
                                                    readonly description: "a numeric or qualitative value, represented as a string";
                                                    readonly type: "string";
                                                };
                                                readonly possible: {
                                                    readonly description: "Number of points possible for this control point";
                                                    readonly type: "string";
                                                };
                                                readonly compliance: {
                                                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                    readonly type: "string";
                                                };
                                                readonly globalgap_levels: {
                                                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                    readonly properties: {
                                                        readonly major_musts: {
                                                            readonly description: "The summary score for all major-must level questions";
                                                            readonly anyOf: readonly [{
                                                                readonly properties: {
                                                                    readonly yes: {
                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly no: {
                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly n_a: {
                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly is_compliant: {
                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                        readonly type: "boolean";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }, {
                                                                readonly properties: {
                                                                    readonly major_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly minor_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly recommended: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }];
                                                        };
                                                        readonly minor_musts: {
                                                            readonly description: "The summary score for all minor-must level questions";
                                                            readonly anyOf: readonly [{
                                                                readonly properties: {
                                                                    readonly yes: {
                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly no: {
                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly n_a: {
                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly is_compliant: {
                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                        readonly type: "boolean";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }, {
                                                                readonly properties: {
                                                                    readonly major_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly minor_must: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                    readonly recommended: {
                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                        readonly properties: {
                                                                            readonly value: {
                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                readonly type: "string";
                                                                            };
                                                                            readonly units: {
                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                readonly type: "string";
                                                                                readonly examples: readonly ["count"];
                                                                            };
                                                                            readonly possible: {
                                                                                readonly description: "Number of points possible for this control point";
                                                                                readonly type: "string";
                                                                            };
                                                                        };
                                                                        readonly type: "object";
                                                                    };
                                                                };
                                                                readonly type: "object";
                                                            }];
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                                readonly canadagap_isautofail: {
                                                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                    readonly type: "boolean";
                                                };
                                                readonly subtotals: {
                                                    readonly description: "Introduced for CanadaGAP.  Represents the sub totals for various combinations of sections as specified by CanadaGAP, as well as the weighting_factor for that combination of sections toward the overall score.  This is needed because the subtotals do not perfectly match the sections, so it exists here as a separate key.  Other audits should just put the subtotal under the section that it goes with.";
                                                    readonly properties: {
                                                        readonly score: {
                                                            readonly description: "Do not use score_core in an audit schema.  It exists to avoid recursive definition of score and subtotals.";
                                                            readonly properties: {
                                                                readonly units: {
                                                                    readonly description: "the units used to interpret the associated value.";
                                                                    readonly type: "string";
                                                                };
                                                                readonly preliminary: {
                                                                    readonly description: "A prelimiary score for an audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly final: {
                                                                    readonly description: "The final score for an audit";
                                                                    readonly properties: {
                                                                        readonly value: {
                                                                            readonly description: "a numeric or qualitative value, represented as a string";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly units: {
                                                                            readonly description: "the units used to interpret the associated value.";
                                                                            readonly type: "string";
                                                                        };
                                                                        readonly possible: {
                                                                            readonly description: "Number of points possible for this control point";
                                                                            readonly type: "string";
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly value: {
                                                                    readonly description: "a numeric or qualitative value, represented as a string";
                                                                    readonly type: "string";
                                                                };
                                                                readonly possible: {
                                                                    readonly description: "Number of points possible for this control point";
                                                                    readonly type: "string";
                                                                };
                                                                readonly compliance: {
                                                                    readonly description: "written description indicating the level of satisfaction of the control point. E.g., \"Total Compliance\", \"Minor Deficiency\", or simply \"Pass\"/\"Fail\".";
                                                                    readonly type: "string";
                                                                };
                                                                readonly globalgap_levels: {
                                                                    readonly description: "GlobalGAP has particular levels of major_musts and minor_must that are entirely unique to GlobalGAP, hence the name.";
                                                                    readonly properties: {
                                                                        readonly major_musts: {
                                                                            readonly description: "The summary score for all major-must level questions";
                                                                            readonly anyOf: readonly [{
                                                                                readonly properties: {
                                                                                    readonly yes: {
                                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly no: {
                                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly n_a: {
                                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly is_compliant: {
                                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                                        readonly type: "boolean";
                                                                                    };
                                                                                };
                                                                                readonly type: "object";
                                                                            }, {
                                                                                readonly properties: {
                                                                                    readonly major_must: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly minor_must: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly recommended: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                };
                                                                                readonly type: "object";
                                                                            }];
                                                                        };
                                                                        readonly minor_musts: {
                                                                            readonly description: "The summary score for all minor-must level questions";
                                                                            readonly anyOf: readonly [{
                                                                                readonly properties: {
                                                                                    readonly yes: {
                                                                                        readonly description: "yes is used to represent the summary count of \"yes\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly no: {
                                                                                        readonly description: "no is used to represent the summary count of \"no\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly n_a: {
                                                                                        readonly description: "n_a is used to represent the summary count of \"Not Applicable\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly is_compliant: {
                                                                                        readonly description: "GlobalGAP has an overall true/false compliance for an audit score";
                                                                                        readonly type: "boolean";
                                                                                    };
                                                                                };
                                                                                readonly type: "object";
                                                                            }, {
                                                                                readonly properties: {
                                                                                    readonly major_must: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Major Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly minor_must: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                    readonly recommended: {
                                                                                        readonly description: "major_must is used to represent the summary count of \"Minor Must\" answers in the audit";
                                                                                        readonly properties: {
                                                                                            readonly value: {
                                                                                                readonly description: "a numeric or qualitative value, represented as a string";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                            readonly units: {
                                                                                                readonly description: "the units used to interpret the associated value.";
                                                                                                readonly type: "string";
                                                                                                readonly examples: readonly ["count"];
                                                                                            };
                                                                                            readonly possible: {
                                                                                                readonly description: "Number of points possible for this control point";
                                                                                                readonly type: "string";
                                                                                            };
                                                                                        };
                                                                                        readonly type: "object";
                                                                                    };
                                                                                };
                                                                                readonly type: "object";
                                                                            }];
                                                                        };
                                                                    };
                                                                    readonly type: "object";
                                                                };
                                                                readonly canadagap_isautofail: {
                                                                    readonly description: "If the audit is scored as autofail, this key should be set to true in the score section.  Otherwise it can either be missing or set to false.  Specific to CanadaGAP";
                                                                    readonly type: "boolean";
                                                                };
                                                            };
                                                            readonly type: "object";
                                                        };
                                                        readonly name: {
                                                            readonly description: "name is a string, typically the name of the object the key appears in.";
                                                            readonly type: "string";
                                                            readonly pattern: "^(?!(indexing|.*-index|_.*)).*$";
                                                        };
                                                        readonly sectionids: {
                                                            readonly description: "An array of section id strings that belong to a subtotal or a sub-section.";
                                                            readonly type: "array";
                                                            readonly items: {
                                                                readonly description: "sectionid is the string id associated with a particular section. sectionid is constructed by prefixing the id with any parent sections, separated by periods (e.g., sectionid '2.3' is a section that is inside of a parent section with sectionid '2').  Note that CanadaGAP also has a special sectionid of \"autofail\" for their autofail items.  All other sectionids that we have seen are of the form <number_or_letter>.<number_or_letter>.<number_or_letter>... with 1 or more numbers";
                                                                readonly type: "string";
                                                            };
                                                        };
                                                        readonly weighting_factor: {
                                                            readonly description: "Introduced for CanadaGAP.  Represents the weight used to combine sections into a total score.";
                                                            readonly type: "string";
                                                            readonly pattern: "^-?[0-9]+(.[0-9]+)?";
                                                        };
                                                    };
                                                    readonly type: "object";
                                                };
                                            };
                                            readonly type: "object";
                                        };
                                    };
                                    readonly type: "object";
                                };
                            };
                        };
                    };
                    readonly type: "object";
                };
            };
        };
        readonly _id: {
            readonly description: "_id identifies a resource in the OADA API.";
            readonly type: "string";
        };
        readonly _rev: {
            readonly description: "_rev is the revision string for a resource in the OADA API.";
            readonly type: "integer";
        };
        readonly _meta: {
            readonly description: "_meta is a link to the meta document for a resources.";
            readonly properties: {
                readonly _id: {
                    readonly description: "_id identifies a resource in the OADA API.";
                    readonly type: "string";
                };
                readonly _rev: {
                    readonly description: "_rev is the revision string for a resource in the OADA API.";
                    readonly type: "integer";
                };
            };
            readonly required: readonly ["_id", "_rev"];
            readonly type: "object";
        };
        readonly _type: {
            readonly enum: readonly ["application/vnd.trellis.audit.globalgap.1+json"];
        };
    };
    readonly additionalProperties: true;
    readonly required: readonly ["_type"];
    readonly type: "object";
    readonly examples: readonly [{
        readonly _type: "application/vnd.trellis.audit.globalgap.1+json";
        readonly certificationid: {
            readonly id_source: "scheme";
            readonly id: "12345-AAAAA-6789";
        };
        readonly scheme: {
            readonly name: "GLOBALGAP";
            readonly version: "5.0-1";
            readonly option: "1";
            readonly modules: readonly [{
                readonly name: "All Farm Base";
            }, {
                readonly name: "Crops Base";
            }, {
                readonly name: "Fruit and Vegetables";
            }];
        };
        readonly certifying_body: {
            readonly name: "SCS Global Services";
            readonly auditor: {
                readonly name: "Aaron Auditor Ault";
            };
        };
        readonly organization: {
            readonly organizationid: {
                readonly id_source: "scheme";
                readonly id: "777777777";
                readonly otherids: readonly [{
                    readonly id_source: "certifying_body";
                    readonly id: "1234567";
                }];
            };
            readonly name: "Noel Produce Masters";
            readonly contacts: readonly [{
                readonly name: "Sam Noel";
            }];
            readonly location: {
                readonly description: "(All sites in same area), Pesticide storage";
                readonly street_address: "44641 SW Plumlee Rd.";
                readonly city: "Nowhere";
                readonly state: "Florida";
                readonly country: "USA";
            };
        };
        readonly scope: {
            readonly notification: "announced";
            readonly description: "";
            readonly operations: readonly [{
                readonly operation_type: "handling";
            }];
            readonly products_observed: readonly [{
                readonly name: "Blueberries";
                readonly first_area: {
                    readonly value: 70;
                    readonly units: "acres";
                };
                readonly further_area: {
                    readonly value: 10.67;
                    readonly units: "acres";
                };
                readonly operations: readonly [{
                    readonly operation_type: "growing";
                    readonly covering_type: "uncovered";
                }, {
                    readonly operation_type: "harvest";
                }];
            }];
            readonly similar_products_not_observed: readonly [{
                readonly name: "Snozzberries";
            }];
            readonly production_sites: readonly [{
                readonly name: "The Big Ranch";
                readonly id: "1234";
                readonly products_observed: readonly [{
                    readonly name: "Blueberries";
                    readonly organic: true;
                    readonly area: {
                        readonly value: "70";
                        readonly units: "acres";
                    };
                    readonly location: {
                        readonly description: "";
                        readonly city: "";
                    };
                }];
            }];
            readonly parallel_production: false;
            readonly parallel_ownership: false;
        };
        readonly conditions_during_audit: {
            readonly FSMS_observed_date: {
                readonly start: "2016-07-26";
                readonly end: "2016-07-26";
            };
            readonly operation_observed_date: {
                readonly start: "2016-07-26";
                readonly end: "2016-07-26";
                readonly duration: {
                    readonly value: "4.5";
                    readonly units: "hours";
                };
            };
        };
        readonly score: {
            readonly is_compliant: false;
            readonly globalgap_levels: {
                readonly major_musts: {
                    readonly yes: {
                        readonly value: "12";
                        readonly units: "count";
                    };
                    readonly no: {
                        readonly value: "1";
                        readonly units: "count";
                    };
                    readonly n_a: {
                        readonly value: "32";
                        readonly units: "count";
                    };
                    readonly is_compliant: false;
                };
                readonly minor_musts: {
                    readonly yes: {
                        readonly value: "12";
                        readonly units: "count";
                    };
                    readonly no: {
                        readonly value: "1";
                        readonly units: "count";
                    };
                    readonly n_a: {
                        readonly value: "32";
                        readonly units: "count";
                    };
                    readonly value: "98.72";
                    readonly units: "%";
                    readonly is_compliant: true;
                };
            };
        };
        readonly sections: readonly [{
            readonly sectionid: "AF";
            readonly name: "All Farm Base";
            readonly sections: readonly [{
                readonly sectionid: "AF 1";
                readonly name: "Site History and Site Management";
                readonly sections: readonly [{
                    readonly sectionid: "AF 1.1";
                    readonly name: "Site History";
                    readonly control_pointids: readonly ["AF 1.1.1", "AF 1.1.2"];
                }, {
                    readonly sectionid: "AF 1.2";
                    readonly name: "Site Management";
                    readonly control_pointids: readonly ["AF 1.2.1", "AF 1.2.2"];
                }];
            }, {
                readonly sectionid: "AF 2";
                readonly name: "Record Keeping And Internal Self-Assessment/Internal Inspection";
                readonly control_pointids: readonly ["AF 2.1", "AF 2.2", "AF 2.3"];
            }];
        }];
        readonly control_points: {
            readonly 'AF 1.1.1': {
                readonly name: "Is there a reference system for each field, orchard, greenhouse, yard, plot, livestock building/pen, and/or other area/location used in production?";
                readonly criteria: readonly ["A physical sign at each field/orchard, greenhouse/yard/plot/livestock building/pen, or other farm area/location", "A farm map, which also identifies the location of water sources, storage/handling facilities, ponds, stables, etc. and that could be cross-referenced to the identification system."];
                readonly globalgap_level: "major_must";
                readonly score: {
                    readonly value: "yes";
                    readonly units: "yes-no-n_a";
                };
                readonly justification: "Site map was available for review. Broken down by Field ID. Variety and acreage is listed on legend indicating which applies to each block. Fuel and drip water line indicated on map.";
            };
        };
    }];
};
export = schema;
