"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.properties = exports.merge = exports.each = exports.$ref = exports.typescript = exports.ianaAssignments = exports.columns = exports.importSchema = exports.iana = exports.rfc = void 0;
const tslib_1 = require("tslib");
const promises_1 = require("node:stream/promises");
const csv_parse_1 = require("csv-parse");
const deep_freeze_node_1 = tslib_1.__importDefault(require("deep-freeze-node"));
const lodash_get_1 = tslib_1.__importDefault(require("lodash.get"));
const lodash_merge_1 = tslib_1.__importDefault(require("lodash.merge"));
function rfc(rfcNumber, section) {
    const fragment = section ? `section-${section}` : '';
    const uri = `https://datatracker.ietf.org/doc/html/rfc${rfcNumber}`;
    return (fragment ? `${uri}#${fragment}` : uri);
}
exports.rfc = rfc;
function iana(protocol, assignment) {
    const baseUri = `https://www.iana.org/assignments/${protocol}`;
    return {
        csv: `${baseUri}/${assignment}.csv`,
        uri: `${baseUri}/${protocol}.xhtml#${assignment}`,
    };
}
exports.iana = iana;
async function importSchema(file) {
    const schema = await import(file);
    if ('$id' in schema) {
        return (0, deep_freeze_node_1.default)(schema);
    }
    return (0, deep_freeze_node_1.default)(schema.default);
}
exports.importSchema = importSchema;
const columnDefaults = ['value', 'description'];
exports.columns = {
    jose: {
        'web-key-parameters': [...columnDefaults, 'kty'],
    },
};
async function ianaAssignments(protocol, assignment) {
    const { csv, uri } = iana(protocol, assignment);
    const cols = (exports.columns[protocol]?.[assignment] ?? columnDefaults);
    const parser = (0, csv_parse_1.parse)({
        skip_empty_lines: true,
        raw: true,
        columns(header) {
            const rest = header.slice(cols.length);
            return [...cols, ...rest.map((n) => n.toLowerCase())];
        },
        cast(value, context) {
            if (context.column === 'reference') {
                try {
                    const r = /\[(?<reference>[^,]+)(?:, (?<section>[^,]*))?]/;
                    const { groups: { reference, section } = {} } = r.exec(value);
                    if (/^rfc/i.test(reference)) {
                        return rfc(Number.parseInt(reference.slice(3), 10), section?.replace(/section ?/i, ''));
                    }
                    return section ? `${reference}, ${section}` : reference;
                }
                catch { }
            }
            return value;
        },
    });
    const { body } = await fetch(csv);
    void (0, promises_1.pipeline)(body, parser, { end: true });
    const records = parser;
    return Object.assign(records, {
        async map(f) {
            const rows = [];
            for await (const { record } of records) {
                rows.push(f(record));
            }
            return rows;
        },
        uri,
    });
}
exports.ianaAssignments = ianaAssignments;
const tsKey = 'tsType';
function typescript(strings, ...values) {
    const tsTypes = values.map((s) => typeof s === 'string'
        ? s
        : tsKey in s
            ? s[tsKey]
            : s.enum.map((v) => JSON.stringify(v)).join('|'));
    return {
        tsType: String.raw({ raw: strings }, ...tsTypes),
    };
}
exports.typescript = typescript;
function toPath(p) {
    const [, ...path] = p.split('/');
    return path.join('.');
}
function get(o, p) {
    if (!p) {
        return o;
    }
    const path = toPath(p);
    return (0, lodash_get_1.default)(o, path);
}
class $Ref {
    $ref;
    #string;
    constructor(schema, p) {
        const d = get(schema, p);
        for (const [key, value] of Object.entries((d ?? {}))) {
            Object.defineProperty(this, key, { value });
        }
        this.#string = d?.pattern;
        const url = new URL(schema.$id ?? '', 'none:/');
        url.hash += p;
        this.$ref = url.toString().replace(/^none:\//, '');
    }
    toString() {
        return this.#string;
    }
}
function $ref(schema, p) {
    return new $Ref(schema, p);
}
exports.$ref = $ref;
function each(a, fun) {
    return Object.assign({}, ...a.map(fun));
}
exports.each = each;
function merge(a, b) {
    return (0, lodash_merge_1.default)(a, b);
}
exports.merge = merge;
function properties(a, b) {
    return {
        properties: (0, lodash_merge_1.default)(a, b),
    };
}
exports.properties = properties;
//# sourceMappingURL=utils.cjs.map